@@ -140,7 +140,7 @@ class Mondo(object):
 
     def make_name2mondoids(
             self, chain: Chain=Chain(),
-            allowed_scope_list: List[Scope]=Scope.EXACT,
+            allowed_scope_list: List[Scope]=None,
             allow_deprecated: bool=False
     ):
         """make a dictionary which maps noramalized name to mondo ids
@@ -171,7 +171,7 @@ class Mondo(object):
 
     def make_rid2mondoids(
             self,
-            allowed_scope_list: List[Scope]=Scope.EXACT,
+            allowed_scope_list: List[Scope]=None,
             allow_deprecated: bool=False
     ):
         """make a dictionary which maps resource id to mondo ids
